<?php
/*
 * Last modification  : 18/03/2005
 *
 * Copyright 2001, 2005 Thomas Belliard, Laurent Delineau, Edouard Hue, Eric Lebrun
 *
 * This file is part of GEPI.
 *
 * GEPI is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * GEPI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GEPI; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * Open a new session
 *
 * Check the provided login and password
 * Register data from the database to the session cookie
 * Log the session
 *
 * Returns true if login succeeded, false otherwise
 *
 * @_login              string                  Login of the user
 * @_password           string                  Password
 *
 * @return              bool                    The session is open
 */

function openSession($_login, $_password)
{
    $sql = "select upper(login) login, password, prenom, nom, statut, now() start, change_mdp from utilisateurs where login = '" . $_login . "' and password = md5('" . $_password . "') and etat != 'inactif'";
    $res_user = sql_query($sql);
    $num_row = sql_count($res_user);
    if ($num_row != 1) {
        return "0";
    } else {
        // Get principal matter of this user
        $sql2 = "select id_matiere from j_professeurs_matieres where id_professeur = '" . $_login . "' order by ordre_matieres limit 1";
        $matiere_princ = sql_query1($sql2);
    }
    $row = sql_row($res_user,0);

    if ((getSettingValue("disable_login")=='yes') and ($row[4] != "administrateur")) {
        return "dl";
        die();
    }


    $test_change_mdp = $row[6];

    // Session starts now
    session_name("GEPI");
    session_start();

    // Is this user already connected ?
    $sql = "select SESSION_ID from log where SESSION_ID = '" . session_id() . "' and LOGIN = '" . $_login . "' and now() between START and END";
    $res = sql_query($sql);
    $num_row = sql_count($res);
    if (($num_row > 0) and isset($_SESSION['start'])) {
        $sql = "update log set END = now() + interval " . getSettingValue("sessionMaxLength") . " minute where SESSION_ID = '" . session_id() . "' and START = '" . $_SESSION['start'] . "'";
        $res = sql_query($sql);
        if ($test_change_mdp == 'y') return "c"; else return "1";
    } else {
        session_unset();
    }
    $_SESSION = array();
    $_SESSION['login'] = $row[0];
    $_SESSION['password'] = $row[1];
    $_SESSION['prenom'] = $row[2];
    $_SESSION['nom'] = $row[3];
    $_SESSION['statut'] = $row[4];
    $_SESSION['start'] = $row[5];
    $_SESSION['matiere'] = $matiere_princ;
    $_SESSION['maxLength'] = getSettingValue("sessionMaxLength");

    // It's a new connection, insert into log
    $sql = "insert into log (LOGIN, START, SESSION_ID, REMOTE_ADDR, USER_AGENT, REFERER, AUTOCLOSE, END) values (
                '" . $_SESSION['login'] . "',
                '" . $_SESSION['start'] . "',
                '" . session_id() . "',
                '" . $_SERVER['REMOTE_ADDR'] . "',
                '" . $_SERVER['HTTP_USER_AGENT'] . "',
                '" . $_SERVER['HTTP_REFERER'] . "',
                '1',
                '" . $_SESSION['start'] . "' + interval " . getSettingValue("sessionMaxLength") . " minute
            )
        ;";
    $res = sql_query($sql);
    if ($test_change_mdp == 'y') return "c"; else return "1";
}

/**
 * Resume a session
 *
 * Check that all the expected data is present
 * Check login / password against database
 * Update the timeout in the log table
 *
 * Returns true if session resumes, false otherwise
 *
 *
 * @return              bool                    The session resumed
 */
function resumeSession()
{
    // Resuming session
    session_name("GEPI");
    session_start();
    if ((!isset($_SESSION)) or (!isset($_SESSION['login']))){
        return "0";
        die();
    }
    if ((getSettingValue("disable_login")=='yes') and ($_SESSION['statut'] != "administrateur")) {
        return "0";
        die();
    }

    // To be removed
    // Validating session data
    $sql = "select password = '" . $_SESSION['password'] . "' PASSWORD, login = '" . $_SESSION['login'] . "' LOGIN, statut = '" . $_SESSION['statut'] . "' STATUT, change_mdp = 'n' CHANGE_MDP from utilisateurs where login = '" . $_SESSION['login'] . "'";

    $res = sql_query($sql);
    $row = sql_row($res, 0);

    // Checking for a timeout
    $sql2 = "select now() > END TIMEOUT from log where SESSION_ID = '" . session_id() . "' and START = '" . $_SESSION['start'] . "'";

    if ($row[0] != "1" || $row[1] != "1" || $row[2] != "1") {
        return "0";
    } else if (sql_query1($sql2)) {
        return "0";
    } else if ($row[3] != "1") {
        return "c";
    } else {
        $sql = "update log set END = now() + interval " . $_SESSION['maxLength'] . " minute where SESSION_ID = '" . session_id() . "' and START = '" . $_SESSION['start'] . "'";
        $res = sql_query($sql);
        return "1";
    }
}

/**
 * Close a session
 *
 * Set the closing time in the logs
 * Destroy all session data
 * @_auto               string                  Session auto-close flag
 * @return              nothing
 */
function closeSession(&$_auto)
{
    session_name("GEPI");
    session_start();
    // Sometimes 'start' may not exist, because the session was previously closed by another window
    // It's not necessary to log this, then
    if (isset($_SESSION['start'])) {
            $sql = "update log set AUTOCLOSE = '" . $_auto . "', END = now() where SESSION_ID = '" . session_id() . "' and START = '" . $_SESSION['start'] . "'";
        $res = sql_query($sql);
    }
    // Dtruit toutes les variables de session
    session_unset();

    // Dtruit le cookie sur le navigateur
    setcookie(session_name(), '', time()-3600);

    /*
    // Pour une gestion plus fine de la suppression du cookie.
    $CookieInfo = session_get_cookie_params();
    if ( (empty($CookieInfo['domain'])) && (empty($CookieInfo['secure'])) ) {
       setcookie(session_name(), '', time()-3600, $CookieInfo['path']);
    } elseif (empty($CookieInfo['secure'])) {
       setcookie(session_name(), '', time()-3600, $CookieInfo['path'], $CookieInfo['domain']);
    } else {
       setcookie(session_name(), '', time()-3600, $CookieInfo['path'], $CookieInfo['domain'], $CookieInfo['secure']);
    }
    */


    // dtruit la session sur le serveur
    session_destroy();
}
?>